@@ -1,7 +1,7 @@
 import pandas as pd
 import pyro
 from random import randint
-from mvnmm import MVNMixtureModel
+from .mvnmm import MVNMixtureModel
 
 def run_inference(cov_df, IS=[], columns=[], lineages=[], k_interval=[10,30], 
         n_runs=1, steps=500, lr=0.005, p=1, convergence=True, initializ=False,
